@@ -3,7 +3,7 @@ import logging
 
 import pytest
 
-from .utils import make_safety_fixture, skipif_known_failing
+from .utils import assert_bool, make_safety_fixture, skipif_known_failing
 
 logging.basicConfig(level=logging.ERROR)
 
@@ -24,10 +24,6 @@ def stale_detected():
     return _safety_state[0].test_and_clear_detected_flag()
 
 
-def assert_bool(val, msg=''):
-    assert val, str(msg)
-
-
 def assert_detected(msg=''):
     assert_bool(stale_detected(), msg=msg)
 
@@ -130,6 +126,19 @@ def test_basic_assignment():
     assert_not_detected("There should be no more dependency issue")
 
 
+def test_empty_list_assignment():
+    run_cell('a = [5]')
+    run_cell('b = a + [6]')
+    run_cell('logging.info(b)')
+    run_cell('a = [6]')
+    run_cell('logging.info(b)')
+    assert_detected('`b` depends on stale `a`')
+    run_cell('b = a + [7]')
+    run_cell('a = []')
+    run_cell('logging.info(b)')
+    assert_detected('`b` depends on stale `a`')
+
+
 # redefined function example from the project prompt
 def test_redefined_function_in_list():
     run_cell("""
@@ -811,6 +820,19 @@ def test_list_mutation_2():
     assert_detected('`x` depends on stale `lst`')
 
 
+@skipif_known_failing
+def test_list_mutation_from_attr():
+    run_cell('s = "hello X world X how X are X you X today?"')
+    run_cell('lst = []')
+    run_cell("""
+for word in s.split('X'):
+    lst.append(word.strip())
+""")
+    run_cell('s = "foobar"')
+    run_cell('logging.info(lst)')
+    assert_detected('`lst` depends on stale `s`')
+
+
 def test_lazy_class_scope_resolution():
     run_cell("""
 class Foo(object):
@@ -1054,6 +1076,22 @@ for i in [a, b, c]:
     assert_not_detected('`i` should not depend on `a` at end of for loop')
 
 
+@skipif_known_failing
+def test_for_loop_partial_dep():
+    run_cell('lst = list(range(10))')
+    run_cell('s = 0')
+    run_cell("""
+for i in range(5):
+    s += lst[i]
+""")
+    run_cell('lst[-1] = 42')
+    run_cell('logging.info(s)')
+    assert_not_detected('`s` does not depend on last entry of `lst`')
+    run_cell('lst[1] = 22')
+    run_cell('logging.info(s)')
+    assert_detected('`s` does depend on second entry of `lst`')
+
+
 def test_same_cell_redefine():
     run_cell('a = 0')
     run_cell("""
@@ -1064,7 +1102,6 @@ a = 42
     assert_not_detected('`b` should not be considered as having stale dependency since `a` changed in same cell as `b`')
 
 
-@skipif_known_failing
 def test_multiple_stmts_in_one_line():
     run_cell('a = 1; b = 2')
     run_cell('x = a + b')
@@ -1184,9 +1221,7 @@ except:
 
 
 def test_attr_dep_from_somewhere_else():
-    run_cell('import sys')
-    run_cell('sys.path.append("./test")')
-    run_cell('import fake')
+    run_cell('import fakelib as fake')
     run_cell('fake.y = 7')
     run_cell('x = fake.y + 1')
     run_cell('fake.y = 42')
@@ -1195,9 +1230,7 @@ def test_attr_dep_from_somewhere_else():
 
 
 def test_attr_use_from_somewhere_else():
-    run_cell('import sys')
-    run_cell('sys.path.append("./test")')
-    run_cell('import fake')
+    run_cell('import fakelib as fake')
     run_cell('x = 7')
     run_cell('fake.y = x + 1')
     run_cell('x = 42')
